/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

package test.apache.skywalking.apm.testcase.customize.service;

import java.util.List;
import java.util.Map;

public class TestService2 {

    public static void staticMethod(String str0, int count) {

    }

    public void method(Object[] objects) {

    }

    public void method(List str0, int count) {

    }

    public Object[] retArray(Object[] objects) {
        return objects;
    }

    public List retList(List str0) {
        return str0;
    }

    public Map retMap(Map map) {
        return map;
    }
}
